@@ -17,11 +17,11 @@ Test::Mock::Redis - use in place of Redis for unit testing
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 =head1 SYNOPSIS
 
@@ -365,7 +365,7 @@ sub keys :method {
 
     return @{[ sort { $a cmp $b }
         grep { exists $self->_stash->{$_} }
-        grep { /$match/ }
+        grep { /^$match/ }
         keys %{ $self->_stash }]};
 }
 
@@ -1519,4 +1519,3 @@ sub ttl {
 
 
 1;
-
